package com.soss.system.mapper;

import com.soss.system.domain.CouponUser;
import com.soss.system.domain.vo.CouponVo;
import org.apache.ibatis.annotations.Param;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 * 用户领取优惠券记录表 Mapper 接口
 * </p>
 *
 * @author caiyt
 * @since 2022-07-21
 */
public interface CouponUserMapper {
    /**
     * 获取优惠券被领取次数
     *
     * @param couponId
     * @return
     */
    int getCouponReceiveCount(@Param("couponId") Integer couponId);

    /**
     * 查询用户的优惠券信息
     *
     * @return
     */
    CouponUser getUserCouponById(@Param("id") Integer id);

    /**
     * 保存用户领取优惠券记录
     *
     * @param couponUser
     * @return
     */
    int insertCouponUser(CouponUser couponUser);

    /**
     * 更新用户领取优惠券记录
     *
     * @param couponUser
     * @return
     */
    int updateCouponUser(CouponUser couponUser);

    /**
     * 查询用户可用优惠券数量
     *
     * @param userId
     * @param nowTime
     * @return
     */
    int getUserAvailableCouponCnt(@Param("userId") Long userId, @Param("nowTime") LocalDateTime nowTime);

    /**
     * 查询用户可用优惠券列表
     *
     * @param userId
     * @param nowTime
     * @return
     */
    List<CouponVo> listUserAvailableCoupon(@Param("userId") Long userId, @Param("nowTime") LocalDateTime nowTime);
}
